What next?
==========

The most powerful features of Abjad are the set of interlocking objects
that structure the system. Find out how Abjad models pitch, duration,
leaves, containers and spanners in the chapters on Abjad fundamentals.
These chapters explain how to work with the basic Abjad components.

Read some of the chapters concerning materials generation to figure
out how to create starting materials.

And then read about structure traversal and manipulation to learn 
how to move around in large pieces of notation and change them 
while you go.

When you get stuck, check out the public interface in
the :doc:`Abjad API </chapters/api/index>`.

When you start to extend Abjad with custom code that you write
for your own scores, read the chapters on developing with Abjad.
These chapters describe how the codebase is laid out, 
how to add documentation and tests to the system, and how to 
contribute code that you write back to the public release of Abjad.
We love contributions from composers working in many different ways. 
So get in touch and consider contributing to the project when the 
time feels right.


Get in touch!
-------------

Please join our two new mailing lists:

**Questions or comments?** 
Join the `abjad-user <http://groups.google.com/group/abjad-user>`__ list.

**Want to contribute?**
Join the `abjad-devel <http://groups.google.com/group/abjad-devel>`__ list.
